{{% set nav_li_class = "nav-item col-12 col-lg-auto" %}}
{{% set nav_a_class = "nav-link py-2 px-0 px-lg-2" %}}

<li class="{{{{nav_li_class}}}}">
    <a aria-current="true" class="{{{{nav_a_class}}}}{{{{' active' if request.url.path == '/'}}}}" href="/">
        Home
    </a>
</li>
