{{% extends 'static_pages/templates/_base.html' %}}

{{% block page_title %}}Home | {{% endblock %}}
{{% block meta_description %}}{Obj} was built with DetaMVC - the fastest way to get to production!{{% endblock %}}

{{% block content %}}

<div class="container mt-5">
    <div class="text-center">
        <img src="{{{{ url_for('static', path='/img/logo.svg') }}}}" class="mb-3">
        <h1>{Obj}</h1>
        <b>Built with DetaMVC</b><br>
        <p>The fastest way to get to production.</p>
    </div>  
</div>

{{% endblock %}}