<!doctype html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width,initial-scale=1">
    <link rel="icon" href="{{{{ url_for('static', path='/img/logo.svg') }}}}" />
    <meta name="theme-color" content="#ffffff">
    <title>{{% block page_title %}}{{% endblock %}}{Obj}</title>
    <meta name="robots" content="{{% block meta_robots %}}index, follow{{% endblock %}}">
    <meta name="description" content="{{% block meta_description %}}{Obj} was built with DetaMVC - the fastest way to get to production!{{% endblock %}}">
    <meta property="og:url" content="{{{{ request.url }}}}">
    <meta property="og:title" content="{{{{ self.page_title() }}}}">
    <meta property="og:description" content="{{{{ self.meta_description() }}}}">
    <meta property="og:image" content="{{% block meta_shared_image %}}{{{{ url_for('static', path='/img/logo.svg') }}}}{{% endblock %}}">
    <meta name="twitter:card" content="summary_large_image">
    <link rel="canonical" href="{{{{ request.url }}}}">

    <script src="{{{{ url_for('static', path='/js/color-modes.js?v=1.0.0') }}}}"></script>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet" crossorigin="anonymous">
    <link rel="stylesheet" href="{{{{ url_for('static', path='/css/stylesheet.css?v=1.0.0') }}}}">
    {{% block meta_additions %}}{{% endblock %}}
  </head>
  <body>
    {{% include 'static_pages/templates/_svg_symbols.html' %}}

    <header class="navbar navbar-expand-lg dmvc-navbar sticky-top">
      <nav aria-label="Main navigation" class="container-xxl flex-wrap flex-lg-nowrap">
  
          <a class="navbar-brand p-0 me-0 me-lg-2" href="/">
              <img height="40"  class="me-2" src="{{{{ url_for('static', path='/img/logo.svg') }}}}">
              <span class="align-middle">{Obj}</span>
          </a>
  
          <button aria-controls="dmvcNavbar" aria-label="Toggle navigation"
                  class="navbar-toggler d-flex d-lg-none order-3 p-2" data-bs-target="#dmvcNavbar"
                  data-bs-toggle="offcanvas" type="button">
              <svg class="bi" height="24"width="24" xmlns="http://www.w3.org/2000/svg">
                  <use href="#sandwich">
                  </use>
              </svg>
          </button>
  
          <div aria-labelledby="dmvcNavbarOffcanvasLabel" class="offcanvas-lg offcanvas-end flex-grow-1"
               data-bs-scroll="true" id="dmvcNavbar" tabindex="-1">
              <div class="offcanvas-header px-4 pb-0">
                  <h5 class="offcanvas-title" id="dmvcNavbarOffcanvasLabel">
                  {Obj}
                  </h5>
                  <button aria-label="Close" class="btn-close" type="button"
                          data-bs-dismiss="offcanvas" data-bs-target="#dmvcNavbar">
                  </button>
              </div>
              <div class="offcanvas-body p-4 pt-0 p-lg-0 justify-content-end">
                  <hr class="d-lg-none"/>
                  <ul class="navbar-nav flex-row flex-wrap">
                      {{% include 'static_pages/templates/_navlinks.html' %}}
                  </ul>
  
                  {{% include 'static_pages/templates/_color_mode.html' %}}
              </div>
          </div>
  
      </nav>
    </header>

    {{% if alert %}}
    <div class="alert alert-{{{{alert.type or 'danger'}}}} alert-dismissible fade show" role="alert">
        {{{{alert.message | safe or alert | safe}}}}
        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
    </div>
    {{% endif %}}

    {{% block content %}}
    {{% endblock %}}

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js" crossorigin="anonymous"></script>
    <script src="{{{{ url_for('static', path='/js/application.js?v=1.0.0') }}}}"></script>
  </body>
</html>