                        <label for="{f}">{F}</label>
                        <select name="{f}" class="form-select">
                            <option value="true"{{{{' selected' if vals.active}}}}>True</option>
                            <option value="false"{{{{' selected' if not vals.active}}}}>False</option>
                        </select>
                    