                        <label for="{f}">{F}</label><br>
                        <input name="{f}" type="hidden" value="{{{{vals.get('{f}', '')}}}}" id="{f}">
                        <trix-editor input="{f}" class="trix-content"></trix-editor><br>
